@@ -50,7 +50,7 @@ def calculate_maxi_min_rjl(data):
                     lst.remove(max_r)
                     lst.remove(min_r)
 
-        return max_rongjilv, min_rongjilv
+        return {'max_rongjilv':max_rongjilv, 'min_rongjilv':min_rongjilv}
     except Exception as e:
         print(e)
         logger.debug(f'{data}出现问题')
@@ -94,7 +94,7 @@ def calculate_maxi_min_lhl(data):
                     lst.remove(max_lhl)
                     lst.remove(min_lhl)
 
-        return max_lhl, min_lhl
+        return {'max_lhl':max_lhl, 'min_lhl':min_lhl}
     except Exception as e:
         print(e)
         print(data)
@@ -138,7 +138,7 @@ def calculate_maxi_min_jzmd(data):
                     lst.remove(max_jzmd)
                     lst.remove(min_jzmd)
 
-        return max_jzmd, min_jzmd
+        return {'max_jzmd':max_jzmd, 'min_jzmd':min_jzmd}
     except Exception as e:
         print(e)
         print(data)
